	SUBROUTINE EASE2SF(iopt,ascale,bscale,fmap_scale,bcols,brows,fr0,fs0)
C
C return selected EASE2 grid information (external interface)
C
C  inputs (integer)
C    iopt: projection type 8=EASE2 N, 9-EASE2 S, 10=EASE2 T/M
C    (note: ascale, bscale should be integer valued)
C    ascale:  scale factor 0..5 grid size is (basesize(ind))/2^isc
C    bscale:  base grid size index   (map units per cell in m
C 
C          NSIDC .grd file for isc=0
C           project type    ind=0     ind=1         ind=3
C	       N         EASE2_N25km EASE2_N30km EASE2_N36km  
C              S         EASE2_S25km EASE2_S30km EASE2_S36km 
C              T/M       EASE2_T25km EASE2_M25km EASE2_M36km 
C
C          cell size (m) for isc=0 (scale is reduced by 2**isc)
C           project type    ind=0     ind=1            ind=3
C	       N          25000.0     30000.0         36000.0
C              S          25000.0     30000.0         36000.0
C              T/M       T25025.26   M25025.26000  M36032.220840584
C	      
C	  for a given base cell size isc is related to NSIDC .grd file names
C	     isc        N .grd name   S .grd name   T .grd name
C	      0	      EASE2_N25km     EASE2_S25km     EASE2_T25km  
C	      1	      EASE2_N12.5km   EASE2_S12.5km   EASE2_T12.5km  
C	      2	      EASE2_N6.25km   EASE2_S6.25km   EASE2_T6.25km  
C	      3	      EASE2_N3.125km  EASE2_S3.125km  EASE2_T3.125km  
C	      4	      EASE2_N1.5625km EASE2_S1.5625km EASE2_T1.5625km  
C
C  outputs (real)
C    fmap_scale               EASE2 map projection pixel size (km)
C    bcols, brows,            EASE2 grid size in pixels
C    fr0, fs0                 EASE2 base projection size in pixels
C
      integer iopt, bcols, brows
      real ascale, bscale, fmap_scale, fr0, fs0
c
      integer isc, ind
      double precision map_equatorial_radius_m, map_eccentricity
      double precision e2, map_reference_latitude
      double precision map_reference_longitude
      double precision map_second_reference_latitude
      double precision sin_phi1, cos_phi1, kz
      double precision map_scale, r0, s0, epsilon 

      isc=int(ascale)
      ind=int(bscale)

      call ease2_map_info(iopt,isc,ind,
     1     map_equatorial_radius_m, map_eccentricity,
     2     e2, map_reference_latitude, map_reference_longitude,
     3     map_second_reference_latitude, sin_phi1, cos_phi1, kz, 
     4     map_scale, bcols, brows, r0, s0, epsilon)

      fmap_scale=map_scale
      fr0=r0
      fs0=s0
      return
      end
